@@ -603,6 +603,41 @@ def _create_hkjc_hkjc_player_model(
         offensive_rating=None,
         defensive_rating=None,
         box_plus_minus=None,
+        ace_percentage=None,
+        double_fault_percentage=None,
+        first_serves_in=None,
+        first_serve_percentage=None,
+        second_serve_percentage=None,
+        break_points_saved=None,
+        return_points_won_percentage=None,
+        winners=None,
+        winners_fronthand=None,
+        winners_backhand=None,
+        unforced_errors=None,
+        unforced_errors_fronthand=None,
+        unforced_errors_backhand=None,
+        serve_points=None,
+        serves_won=None,
+        serves_aces=None,
+        serves_unreturned=None,
+        serves_forced_error_percentage=None,
+        serves_won_in_three_shots_or_less=None,
+        serves_wide_percentage=None,
+        serves_body_percentage=None,
+        serves_t_percentage=None,
+        serves_wide_deuce_percentage=None,
+        serves_body_deuce_percentage=None,
+        serves_t_deuce_percentage=None,
+        serves_wide_ad_percentage=None,
+        serves_body_ad_percentage=None,
+        serves_t_ad_percentage=None,
+        serves_net_percentage=None,
+        serves_wide_direction_percentage=None,
+        shots_deep_percentage=None,
+        shots_deep_wide_percentage=None,
+        shots_foot_errors_percentage=None,
+        shots_unknown_percentage=None,
+        points_won_percentage=None,
     )
 
 
